==> estateplat-common-1.2.3-20180425.071908-67-sources.jar: cn/gtmap/estateplat/model/server/core/BdcJsydzjdsyq.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Table;
import java.util.Date;

/**
 * 建设用地使用权、宅基地使用权登记信息
 * Created by lst on 2015/3/18
 */
@Table(name = "bdc_jsydzjdsyq")
public class BdcJsydzjdsyq extends QllxParent implements QllxVo{
    /* @Id
     private String qlid;//权利Id
     private String bdcdyid;//不动产单元Id*/
    private Double qdjg;//取得价格
    private Date syksqx;//使用开始期限
    private Date syjsqx;//使用结束期限

    private Double syqmj;//使用权面积（m2）
    private String qllx;//权利类型
    /* private String proid;//项目ID*/
    private String gyqk;//共有情况

    private String fj;//附记

    private Integer qszt;//权属状态

    private String crhtbh;//出让合同编号

    private String zrqyh;//转让契约号

    private Double zrjg;//转让价格

    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 土地使用开始期限2
     */
    private Date syksqx2;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 土地使用结束期限2
     */
    private Date syjsqx2;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 土地使用开始期限3
     */
    private Date syksqx3;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 土地使用结束期限3
     */
    private Date syjsqx3;
    private String zxyy;//注销原因
    private String zxdbr;//注销登簿人
    private Date zxdbsj;//注销登薄时间
    private Double syfttdmj;//剩余分摊土地面积
    private Double dytdmj;//独用土地面积(m2)
    private Double fttdmj;//分摊土地面积(m2)

    /**
     * @author <a href="mailto:liujie@gtmap.cn">liujie</a>
     * @description bdc_jsydzjdsyq表增加冗余字段bdcdyh、bdcdybh、zl
     */
    private String bdcdyh; //不动产单元号

    private String bdcdybh; //不动产单元编号

    private String zl; //坐落

    public String getBdcdyh() {
        return bdcdyh;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    public String getBdcdybh() {
        return bdcdybh;
    }

    public void setBdcdybh(String bdcdybh) {
        this.bdcdybh = bdcdybh;
    }

    public String getZl() {
        return zl;
    }

    public void setZl(String zl) {
        this.zl = zl;
    }

    public String getZxyy() {
        return zxyy;
    }

    public void setZxyy(String zxyy) {
        this.zxyy = zxyy;
    }

    public String getZxdbr() {
        return zxdbr;
    }

    public void setZxdbr(String zxdbr) {
        this.zxdbr = zxdbr;
    }

    public Date getZxdbsj() {
        return zxdbsj;
    }

    public void setZxdbsj(Date zxdbsj) {
        this.zxdbsj = zxdbsj;
    }


    public java.lang.Integer getQszt() {
        return qszt;
    }

    public void setQszt(java.lang.Integer qszt) {
        this.qszt = qszt;
    }


    public Double getQdjg() {
        return qdjg;
    }

    public void setQdjg(Double qdjg) {
        this.qdjg = qdjg;
    }

    public Date getSyksqx() {
        return syksqx;
    }

    public void setSyksqx(Date syksqx) {
        this.syksqx = syksqx;
    }

    public Date getSyjsqx() {
        return syjsqx;
    }

    public void setSyjsqx(Date syjsqx) {
        this.syjsqx = syjsqx;
    }

    public Double getSyqmj() {
        return syqmj;
    }

    public void setSyqmj(Double syqmj) {
        this.syqmj = syqmj;
    }

    public String getQllx() {
        return qllx;
    }

    public void setQllx(String qllx) {
        this.qllx = qllx;
    }

    public String getGyqk() {
        return gyqk;
    }

    public void setGyqk(String gyqk) {
        this.gyqk = gyqk;
    }


    public String getFj() {
        return fj;
    }

    public void setFj(String fj) {
        this.fj = fj;
    }


    public Date getSyksqx2() {
        return syksqx2;
    }

    public void setSyksqx2(Date syksqx2) {
        this.syksqx2 = syksqx2;
    }

    public Date getSyjsqx2() {
        return syjsqx2;
    }

    public void setSyjsqx2(Date syjsqx2) {
        this.syjsqx2 = syjsqx2;
    }

    public Date getSyksqx3() {
        return syksqx3;
    }

    public void setSyksqx3(Date syksqx3) {
        this.syksqx3 = syksqx3;
    }

    public Date getSyjsqx3() {
        return syjsqx3;
    }

    public void setSyjsqx3(Date syjsqx3) {
        this.syjsqx3 = syjsqx3;
    }

    public String getCrhtbh() {
        return crhtbh;
    }

    public void setCrhtbh(String crhtbh) {
        this.crhtbh = crhtbh;
    }

    public String getZrqyh() {
        return zrqyh;
    }

    public void setZrqyh(String zrqyh) {
        this.zrqyh = zrqyh;
    }

    public Double getZrjg() {
        return zrjg;
    }

    public void setZrjg(Double zrjg) {
        this.zrjg = zrjg;
    }
    public Double getSyfttdmj() {
        return syfttdmj;
    }

    public void setSyfttdmj(Double syfttdmj) {
        this.syfttdmj = syfttdmj;
    }

    public Double getDytdmj() {
        return dytdmj;
    }

    public void setDytdmj(Double dytdmj) {
        this.dytdmj = dytdmj;
    }

    public Double getFttdmj() {
        return fttdmj;
    }

    public void setFttdmj(Double fttdmj) {
        this.fttdmj = fttdmj;
    }
}

==> estateplat-common-1.2.3-20180710.065627-144-sources.jar: cn/gtmap/estateplat/model/server/core/BdcJsydzjdsyq.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Table;
import java.util.Date;

/**
 * 建设用地使用权、宅基地使用权登记信息
 * Created by lst on 2015/3/18
 */
@Table(name = "bdc_jsydzjdsyq")
public class BdcJsydzjdsyq extends QllxParent implements QllxVo{
    /* @Id
     private String qlid;//权利Id
     private String bdcdyid;//不动产单元Id*/
    private Double qdjg;//取得价格
    private Date syksqx;//使用开始期限
    private Date syjsqx;//使用结束期限

    private Double syqmj;//使用权面积（m2）
    private String qllx;//权利类型
    /* private String proid;//项目ID*/
    private String gyqk;//共有情况

    private String fj;//附记

    private Integer qszt;//权属状态

    private String crhtbh;//出让合同编号

    private String zrqyh;//转让契约号

    private Double zrjg;//转让价格

    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 土地使用开始期限2
     */
    private Date syksqx2;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 土地使用结束期限2
     */
    private Date syjsqx2;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 土地使用开始期限3
     */
    private Date syksqx3;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 土地使用结束期限3
     */
    private Date syjsqx3;
    private String zxyy;//注销原因
    private String zxdbr;//注销登簿人
    private Date zxdbsj;//注销登薄时间
    private Double syfttdmj;//剩余分摊土地面积
    private Double dytdmj;//独用土地面积(m2)
    private Double fttdmj;//分摊土地面积(m2)

    /**
     * @author <a href="mailto:liujie@gtmap.cn">liujie</a>
     * @description bdc_jsydzjdsyq表增加冗余字段bdcdyh、bdcdybh、zl
     */
    private String bdcdyh; //不动产单元号

    private String bdcdybh; //不动产单元编号

    private String zl; //坐落
    private String qlqtzk; //权利其他状况

    public String getBdcdyh() {
        return bdcdyh;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    public String getBdcdybh() {
        return bdcdybh;
    }

    public void setBdcdybh(String bdcdybh) {
        this.bdcdybh = bdcdybh;
    }

    public String getZl() {
        return zl;
    }

    public void setZl(String zl) {
        this.zl = zl;
    }

    public String getZxyy() {
        return zxyy;
    }

    public void setZxyy(String zxyy) {
        this.zxyy = zxyy;
    }

    public String getZxdbr() {
        return zxdbr;
    }

    public void setZxdbr(String zxdbr) {
        this.zxdbr = zxdbr;
    }

    public Date getZxdbsj() {
        return zxdbsj;
    }

    public void setZxdbsj(Date zxdbsj) {
        this.zxdbsj = zxdbsj;
    }


    public java.lang.Integer getQszt() {
        return qszt;
    }

    public void setQszt(java.lang.Integer qszt) {
        this.qszt = qszt;
    }


    public Double getQdjg() {
        return qdjg;
    }

    public void setQdjg(Double qdjg) {
        this.qdjg = qdjg;
    }

    public Date getSyksqx() {
        return syksqx;
    }

    public void setSyksqx(Date syksqx) {
        this.syksqx = syksqx;
    }

    public Date getSyjsqx() {
        return syjsqx;
    }

    public void setSyjsqx(Date syjsqx) {
        this.syjsqx = syjsqx;
    }

    public Double getSyqmj() {
        return syqmj;
    }

    public void setSyqmj(Double syqmj) {
        this.syqmj = syqmj;
    }

    public String getQllx() {
        return qllx;
    }

    public void setQllx(String qllx) {
        this.qllx = qllx;
    }

    public String getGyqk() {
        return gyqk;
    }

    public void setGyqk(String gyqk) {
        this.gyqk = gyqk;
    }


    public String getFj() {
        return fj;
    }

    public void setFj(String fj) {
        this.fj = fj;
    }


    public Date getSyksqx2() {
        return syksqx2;
    }

    public void setSyksqx2(Date syksqx2) {
        this.syksqx2 = syksqx2;
    }

    public Date getSyjsqx2() {
        return syjsqx2;
    }

    public void setSyjsqx2(Date syjsqx2) {
        this.syjsqx2 = syjsqx2;
    }

    public Date getSyksqx3() {
        return syksqx3;
    }

    public void setSyksqx3(Date syksqx3) {
        this.syksqx3 = syksqx3;
    }

    public Date getSyjsqx3() {
        return syjsqx3;
    }

    public void setSyjsqx3(Date syjsqx3) {
        this.syjsqx3 = syjsqx3;
    }

    public String getCrhtbh() {
        return crhtbh;
    }

    public void setCrhtbh(String crhtbh) {
        this.crhtbh = crhtbh;
    }

    public String getZrqyh() {
        return zrqyh;
    }

    public void setZrqyh(String zrqyh) {
        this.zrqyh = zrqyh;
    }

    public Double getZrjg() {
        return zrjg;
    }

    public void setZrjg(Double zrjg) {
        this.zrjg = zrjg;
    }
    public Double getSyfttdmj() {
        return syfttdmj;
    }

    public void setSyfttdmj(Double syfttdmj) {
        this.syfttdmj = syfttdmj;
    }

    public Double getDytdmj() {
        return dytdmj;
    }

    public void setDytdmj(Double dytdmj) {
        this.dytdmj = dytdmj;
    }

    public Double getFttdmj() {
        return fttdmj;
    }

    public void setFttdmj(Double fttdmj) {
        this.fttdmj = fttdmj;
    }

    public String getQlqtzk() {
        return qlqtzk;
    }

    public void setQlqtzk(String qlqtzk) {
        this.qlqtzk = qlqtzk;
    }
}
